restart

package
v2.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2024 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Overview

Package restart provides primitives for gracefully restarting l3afd

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddSymlink(sPath, symlink string) error

AddSymlink to add symlink

func Convert

func Convert(ctx context.Context, t models.L3AFALLHOSTDATA, hostconfig *config.Config) (*bpfprogs.NFConfigs, error)

Convert will produce *bpfprogs.NFConfigs from deserilzed l3afd state

func GetNetListener

func GetNetListener(fd int, fname string) (*net.TCPListener, error)

GetNetListener will get tcp listner from provided file descriptor

func GetNewVersion

func GetNewVersion(artifactName, oldVersion, newVersion string, conf *config.Config) error

GetNewVersion will download new version make it ready to execute

func ReadSymlink(symlink string) (string, error)

ReadSymlink to read symlink

func RemoveSymlink(symlink string) error

RemoveSymlink to remove symlink

func RollBackSymlink(oldCfgPath, oldBinPath string, oldVersion, newVersion string, conf *config.Config) error

RollBackSymlink will rollback binary & cfgfile symlinks to old version

func SetMetrics

func SetMetrics(t models.L3AFALLHOSTDATA)

SetMetrics will populate all stats from models.L3AFALLHOSTDATA

Types

This section is empty.

Jump to