Documentation
¶
Overview ¶
Package restart provides primitives for gracefully restarting l3afd
Index ¶
- func AddSymlink(sPath, symlink string) error
- func Convert(ctx context.Context, t models.L3AFALLHOSTDATA, hostconfig *config.Config) (*bpfprogs.NFConfigs, error)
- func GetNetListener(fd int, fname string) (*net.TCPListener, error)
- func GetNewVersion(artifactName, oldVersion, newVersion string, conf *config.Config) error
- func ReadSymlink(symlink string) (string, error)
- func RemoveSymlink(symlink string) error
- func RollBackSymlink(oldCfgPath, oldBinPath string, oldVersion, newVersion string, ...) error
- func SetMetrics(t models.L3AFALLHOSTDATA)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Convert ¶
func Convert(ctx context.Context, t models.L3AFALLHOSTDATA, hostconfig *config.Config) (*bpfprogs.NFConfigs, error)
Convert will produce *bpfprogs.NFConfigs from deserilzed l3afd state
func GetNetListener ¶
func GetNetListener(fd int, fname string) (*net.TCPListener, error)
GetNetListener will get tcp listner from provided file descriptor
func GetNewVersion ¶
GetNewVersion will download new version make it ready to execute
func RollBackSymlink ¶
func RollBackSymlink(oldCfgPath, oldBinPath string, oldVersion, newVersion string, conf *config.Config) error
RollBackSymlink will rollback binary & cfgfile symlinks to old version
func SetMetrics ¶
func SetMetrics(t models.L3AFALLHOSTDATA)
SetMetrics will populate all stats from models.L3AFALLHOSTDATA
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.